
dnl Try to figure out what libraries are required for the demos

AC_DEFUN(AC_CHECK_SDB,
[
AC_ARG_WITH(gdbm,
	[  --with-gdbm             enable trivial Gdbm queries],
	[ if test "$withval" != "no"; then
		LDFLAGS_CFG="$LDFLAGS_CFG -lgdbm"
		AC_CHECK_LIB(gdbm, gdbm_open,
			[echo "gdbm found"
			LDFLAGS="$LDFLAGS -lgdbm"
			AC_DEFINE([HAVE_LIBGDBM], 1, [#undef HAVE_LIBGDBM])],
			[echo "gdbm not found"
			exit 1])
	fi ])
AC_ARG_WITH(lago,
	[  --with-lago             enable Lago database queries],
	[ if test "$withval" != "no"; then
		LDFLAGS_CFG="$LDFLAGS_CFG -L/usr/local/lago/lib -llago"
		LDFLAGS="$LDFLAGS -L/usr/local/lago/lib"
		AC_CHECK_LIB(lago, Lquery,
			[echo "lago found"
			LDFLAGS="$LDFLAGS -llago"
			AC_DEFINE([HAVE_LIBLAGO], 1, [#undef HAVE_LIBLAGO])],
			[echo "lago not found"
			exit 1])
	fi ])

AC_ARG_WITH(mysql,
	[  --with-mysql            enable Mysql database queries],
	[ AC_CHECK_PROG(HAVE_MYSQL_CONFIG, mysql_config, yes, no)
	if test "$HAVE_MYSQL_CONFIG" = "yes"; then
		echo "mysql_config found"
		LDFLAGS_CFG="$LDFLAGS_CFG `mysql_config --libs`"
		LDFLAGS="$LDFLAGS `mysql_config --libs`"
		CFLAGS_CFG="$CFLAGS_CFG `mysql_config --cflags`"
		CFLAGS="$CFLAGS `mysql_config --cflags`"
		AC_DEFINE([HAVE_LIBMYSQLCLIENT], 1, [#undef HAVE_LIBMYSQLCLIENT])
	else
		echo "mysql_config not found"
		exit 1
	fi ])

AC_ARG_WITH(sqlite,
	[  --with-sqlite           enable Sqlite database queries],
	[ if test "$withval" != "no"; then
		LDFLAGS_CFG="$LDFLAGS_CFG -lsqlite -lgdbm"
		AC_CHECK_LIB(gdbm, dbm_open,
			[echo "gdbm found"
			LDFLAGS="$LDFLAGS -lgdbm"
			AC_DEFINE([HAVE_LIBGDBM], 1, [#undef HAVE_LIBGDBM])],
			[echo "gdbm not found"
			exit 1])
		AC_CHECK_LIB(sqlite, sqlite_open,
			[echo "sqlite found"
			LDFLAGS="$LDFLAGS -lsqlite"
			AC_DEFINE([HAVE_LIBSQLITE], 1, [#undef HAVE_LIBSQLITE])],
			[echo "sqlite not found"
			exit 1])
	fi ])

AC_ARG_WITH(mimer,
	[  --with-mimer            enable Mimer database support],
	[ if test "$withval" != "no"; then
		LDFLAGS_CFG="$LDFLAGS_CFG -lmimer"
		AC_CHECK_LIB(mimer, SQLAllocConnect,
			[echo "mimer found"
			LDFLAGS="$LDFLAGS -lmimer"
			AC_DEFINE([HAVE_LIBMIMER], 1, [#undef HAVE_LIBMIMER])],
			[echo "mimer not found"
			exit 1])
	fi ])

AC_ARG_WITH(postgres,
	[  --with-postgres         enable Postgres database queries],
	[ if test "$withval" != "no"; then
		CFLAGS_CFG="$CFLAGS_CFG -I/usr/local/pgsql/include"
		LDFLAGS_CFG="$LDFLAGS_CFG -L/usr/local/pgsql/lib -lpq"
		CFLAGS="$CFLAGS -I/usr/local/pgsql/include"
		LDFLAGS="$LDFLAGS -L/usr/local/pgsql/lib"
		AC_CHECK_LIB(pq, PQsetdbLogin,
			[echo "pq found"
			LDFLAGS="$LDFLAGS -lpq"
			AC_DEFINE([HAVE_LIBPQ], 1, [#undef HAVE_LIBPQ])],
			[echo "pq not found"
			exit 1])
	fi ])

AC_ARG_WITH(oracle,
	[  --with-oracle           enable Oracle database queries],
	[ if test "$withval" != "no"; then
		CFLAGS_CFG="$CFLAGS_CFG -L$ORACLE_HOME/rdbms/demo"
		LDFLAGS_CFG="$LDFLAGS_CFG -L$ORACLE_HOME/lib -lclntsh"
		CFLAGS="$CFLAGS -I$ORACLE_HOME/rdbms/demo"
		LDFLAGS="$LDFLAGS -L$ORACLE_HOME/lib"
		AC_CHECK_LIB(clntsh, ologof,
			[echo "clntsh found"
			LDFLAGS="$LDFLAGS -lclntsh"
			AC_DEFINE([HAVE_LIBCLNTSH], 1, [#undef HAVE_LIBCLNTSH])],
			[echo "clntsh not found"
			exit 1])
	fi ])

AC_ARG_WITH(odbc,
	[  --with-odbc=library     enable database queries over ODBC],
	[ case "$withval" in
	yes )
		ODBCLIB=odbc
		;;
	* )
		ODBCLIB="$withval"
		;;
	esac
	echo "ODBCLIB=$ODBCLIB"
	if test "$ODBCLIB" != "no"; then
		LDFLAGS_CFG="$LDFLAGS_CFG -l$ODBCLIB"
		AC_CHECK_LIB($ODBCLIB, main,
			[echo "$ODBCLIB found"
			LDFLAGS="$LDFLAGS -l$ODBCLIB"
			AC_CHECK_HEADERS(windows.h)
			AC_DEFINE([HAVE_LIBODBC], 1, [#undef HAVE_LIBODBC])],
			[echo "$ODBCLIB not found"
			exit 1])
	else
		echo "ODBCLIB=$ODBCLIB"
	fi ])

if test "$GCC" = "yes"; then
	CFLAGS="-Wall $CFLAGS"
fi

AC_SUBST(CFLAGS_CFG)
AC_SUBST(LDFLAGS_CFG)
])

